'use strict';

var _reduxSagaTestPlan = require('redux-saga-test-plan');

var _reduxOfflineStatus = require('redux-offline-status');

var _constants = require('redux-persist/constants');

var _requestQueue = require('./requestQueue.actions');

var _requestQueue2 = require('./requestQueue.sagas');

describe('queueRequest Saga', function () {
  var action = {
    type: 'TEST_QUEUE',
    id: '1234',
    url: 'https://google.com',
    payload: undefined,
    method: 'POST'
  };

  it('dispatches a QUEUE_REQUEST with required params', function () {
    return (0, _reduxSagaTestPlan.expectSaga)(_requestQueue2.queueRequest, action).put((0, _requestQueue.queueRequestAction)(action)).run();
  });

  it('dispatches a EXECUTE_QUEUE after the request is queued', function () {
    return (0, _reduxSagaTestPlan.expectSaga)(_requestQueue2.queueRequest, action).put((0, _requestQueue.queueRequestAction)(action)).put(_requestQueue.executeQueueAction).run();
  });
});

describe('watchExecuteQueue Saga', function () {
  it('takes the latest EXECUTE_QUEUE online and triggers executeQueue', function () {
    (0, _reduxSagaTestPlan.testSaga)(_requestQueue2.watchExecuteQueue).next().takeLatestEffect(_requestQueue.EXECUTE_QUEUE, _requestQueue2.executeQueue);
  });
});

describe('watchOnline Saga', function () {
  it('takes the latest ONLINE action and triggers executeQueue', function () {
    return (0, _reduxSagaTestPlan.testSaga)(_requestQueue2.watchOnline).next().takeLatestEffect(_reduxOfflineStatus.ONLINE, _requestQueue2.executeQueue);
  });
});

describe('waitForRehydrate Saga', function () {
  it('waits for the REHYDRATE event', function () {
    return (0, _reduxSagaTestPlan.expectSaga)(_requestQueue2.waitForRehydrate).take(_constants.REHYDRATE).silentRun();
  });

  it('on REHYDRATE it dispatches EXECUTE_QUEUE', function () {
    return (0, _reduxSagaTestPlan.expectSaga)(_requestQueue2.waitForRehydrate).dispatch({ type: _constants.REHYDRATE }).put(_requestQueue.executeQueueAction).run();
  });
});