'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.executeQueue = executeQueue;
exports.queueRequest = queueRequest;
exports.watchExecuteQueue = watchExecuteQueue;
exports.watchOnline = watchOnline;
exports.waitForRehydrate = waitForRehydrate;
exports.requestQueueSagas = requestQueueSagas;

var _effects = require('redux-saga/effects');

var _requestQueue = require('./requestQueue.actions');

var _reduxOfflineStatus = require('redux-offline-status');

var _constants = require('redux-persist/constants');

var _requestQueue2 = require('./requestQueue.getters');

var _request = require('../request/request.sagas');

var _marked = /*#__PURE__*/regeneratorRuntime.mark(executeQueue),
    _marked2 = /*#__PURE__*/regeneratorRuntime.mark(queueRequest),
    _marked3 = /*#__PURE__*/regeneratorRuntime.mark(watchExecuteQueue),
    _marked4 = /*#__PURE__*/regeneratorRuntime.mark(watchOnline),
    _marked5 = /*#__PURE__*/regeneratorRuntime.mark(waitForRehydrate),
    _marked6 = /*#__PURE__*/regeneratorRuntime.mark(requestQueueSagas);

function executeQueue() {
  var requestQueue, requests;
  return regeneratorRuntime.wrap(function executeQueue$(_context) {
    while (1) {
      switch (_context.prev = _context.next) {
        case 0:
          _context.next = 2;
          return (0, _effects.select)(_requestQueue2.getRequestQueue);

        case 2:
          requestQueue = _context.sent;
          requests = requestQueue.map(function (request) {
            return (0, _effects.fork)(_request.fetchQueuedRequest, request.relatedAction);
          });
          _context.next = 6;
          return (0, _effects.all)(requests);

        case 6:
          return _context.abrupt('return', _context.sent);

        case 7:
        case 'end':
          return _context.stop();
      }
    }
  }, _marked, this);
}

function queueRequest(action) {
  return regeneratorRuntime.wrap(function queueRequest$(_context2) {
    while (1) {
      switch (_context2.prev = _context2.next) {
        case 0:
          _context2.next = 2;
          return (0, _effects.put)((0, _requestQueue.queueRequestAction)(action));

        case 2:
          _context2.next = 4;
          return (0, _effects.put)(_requestQueue.executeQueueAction);

        case 4:
        case 'end':
          return _context2.stop();
      }
    }
  }, _marked2, this);
}

function watchExecuteQueue() {
  return regeneratorRuntime.wrap(function watchExecuteQueue$(_context3) {
    while (1) {
      switch (_context3.prev = _context3.next) {
        case 0:
          _context3.next = 2;
          return (0, _effects.takeLatest)(_requestQueue.EXECUTE_QUEUE, executeQueue);

        case 2:
        case 'end':
          return _context3.stop();
      }
    }
  }, _marked3, this);
}

function watchOnline() {
  return regeneratorRuntime.wrap(function watchOnline$(_context4) {
    while (1) {
      switch (_context4.prev = _context4.next) {
        case 0:
          _context4.next = 2;
          return (0, _effects.takeLatest)(_reduxOfflineStatus.ONLINE, executeQueue);

        case 2:
        case 'end':
          return _context4.stop();
      }
    }
  }, _marked4, this);
}

function waitForRehydrate() {
  return regeneratorRuntime.wrap(function waitForRehydrate$(_context5) {
    while (1) {
      switch (_context5.prev = _context5.next) {
        case 0:
          _context5.next = 2;
          return (0, _effects.take)(_constants.REHYDRATE);

        case 2:
          _context5.next = 4;
          return (0, _effects.put)(_requestQueue.executeQueueAction);

        case 4:
        case 'end':
          return _context5.stop();
      }
    }
  }, _marked5, this);
}

function requestQueueSagas() {
  return regeneratorRuntime.wrap(function requestQueueSagas$(_context6) {
    while (1) {
      switch (_context6.prev = _context6.next) {
        case 0:
          _context6.next = 2;
          return (0, _effects.all)([(0, _effects.spawn)(watchOnline), (0, _effects.spawn)(watchExecuteQueue), (0, _effects.spawn)(waitForRehydrate)]);

        case 2:
        case 'end':
          return _context6.stop();
      }
    }
  }, _marked6, this);
}